@@ -47,7 +47,7 @@ $actions{graph} = sub ($) {
   # get numbers
   my $cnt_deny = dbcount($dbh, "ts_ok IS NULL");
   my $clause = "NOT ts_ok IS NULL AND " .
-               "$config{delay_permit} > ts_latest - ts_entry";
+               "ts_entry + $config{delay_permit} > ts_latest";
   my $cnt_halfopen = dbcount($dbh, $clause);
   my $cnt_all = dbcount($dbh, "");
   my $cnt_permit;
@@ -133,7 +133,7 @@ $actions{graph} = sub ($) {
 $actions{clean} = sub ($) {
   my ($dbh) = @_;
   my $sql = "DELETE FROM graylist WHERE NOT ts_ok IS NULL AND " .
-            "$config{delay_permit} > ts_latest - ts_entry AND " .
+            "ts_entry + $config{delay_permit} > ts_latest AND " .
             "now() - $config{delay_halfopen} >= ts_entry";
   $dbh->do($sql);
 };
