@@ -20,7 +20,7 @@ $DEFAULTS{owner}		= "postfix";
 $DEFAULTS{rights}		= "0600";
 $DEFAULTS{backlog}		= "128";
 $DEFAULTS{pidfile}		= "/var/run/graypold.pid";
-$DEFAULTS{user}			= "nobody";
+$DEFAULTS{user}			= "graylist";
 
 $DEFAULTS{lockfile}		= "/var/lock/graycron.lock";
 $DEFAULTS{rrdfile}		= "/var/db/graylist.rrd";
