@@ -9,7 +9,7 @@ CREATE TABLE graylist (
   ts_entry  DATETIME     NOT NULL,
   ts_latest DATETIME     NOT NULL,
   ts_ok     DATETIME,
-  PRIMARY KEY (ip, sender, recipient)
+  PRIMARY KEY (ip, sender(100), recipient(100))
 );
 
 CREATE TABLE mailcount (
@@ -17,7 +17,7 @@ CREATE TABLE mailcount (
   ip        VARCHAR(39)  NOT NULL,
   username  VARCHAR(255) NOT NULL,
   sender    VARCHAR(255) NOT NULL,
-  recipient VARCHAR(255) NOT NULL,
+  recipient LONGTEXT     NOT NULL,
   count     INTEGER      NOT NULL,
   instance  VARCHAR(255) NOT NULL,
   ts_entry  DATETIME     NOT NULL,
@@ -27,4 +27,4 @@ CREATE TABLE mailcount (
 
 CREATE INDEX graylist_ts_ok_idx ON graylist (ts_ok);
 CREATE INDEX graylist_ts_entry_idx ON graylist (ts_entry);
---CREATE INDEX graylist_halfopen_idx ON graylist ((ts_latest-ts_entry));
+CREATE INDEX graylist_ts_latest_idx ON graylist (ts_latest);
